==> zio-aws-kafka_2.13-7.21.15.13-sources.jar: zio/aws/kafka/model/ListClusterOperationsV2Request.scala <==
package zio.aws.kafka.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kafka.model.primitives.{MaxResults, __string}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListClusterOperationsV2Request(
    clusterArn: __string,
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request = {
    import ListClusterOperationsV2Request.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request
      .builder()
      .clusterArn(clusterArn: java.lang.String)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ListClusterOperationsV2Request.ReadOnly =
    zio.aws.kafka.model.ListClusterOperationsV2Request.wrap(buildAwsValue())
}
object ListClusterOperationsV2Request {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ListClusterOperationsV2Request =
      zio.aws.kafka.model.ListClusterOperationsV2Request(
        clusterArn,
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def clusterArn: __string
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[__string]
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request
  ) extends zio.aws.kafka.model.ListClusterOperationsV2Request.ReadOnly {
    override val clusterArn: __string = impl.clusterArn(): __string
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.kafka.model.primitives.MaxResults(value))
    override val nextToken: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request
  ): zio.aws.kafka.model.ListClusterOperationsV2Request.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-kafka_3-6.20.162.1-sources.jar: zio/aws/kafka/model/ListClusterOperationsV2Request.scala <==
package zio.aws.kafka.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kafka.model.primitives.{MaxResults, __string}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListClusterOperationsV2Request(
    clusterArn: __string,
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request = {
    import ListClusterOperationsV2Request.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request
      .builder()
      .clusterArn(clusterArn: java.lang.String)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ListClusterOperationsV2Request.ReadOnly =
    zio.aws.kafka.model.ListClusterOperationsV2Request.wrap(buildAwsValue())
}
object ListClusterOperationsV2Request {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ListClusterOperationsV2Request =
      zio.aws.kafka.model.ListClusterOperationsV2Request(
        clusterArn,
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def clusterArn: __string
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[__string]
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request
  ) extends zio.aws.kafka.model.ListClusterOperationsV2Request.ReadOnly {
    override val clusterArn: __string = impl.clusterArn(): __string
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.kafka.model.primitives.MaxResults(value))
    override val nextToken: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ListClusterOperationsV2Request
  ): zio.aws.kafka.model.ListClusterOperationsV2Request.ReadOnly = new Wrapper(
    impl
  )
}
